@@ -50,13 +50,11 @@ pcl::registration::CorrespondenceRejectorFeatures::getRemainingCorrespondences(
   // For each set of features, go over each correspondence from input_correspondences_
   for (std::size_t i = 0; i < input_correspondences_->size(); ++i) {
     // Go over the map of features
-    for (FeaturesMap::const_iterator it = features_map_.begin();
-         it != features_map_.end();
-         ++it) {
+    for (const auto& feature : features_map_) {
       // Check if the score in feature space is above the given threshold
       // (assume that the number of feature correspondenecs is the same as the number of
       // point correspondences)
-      if (!it->second->isCorrespondenceValid(static_cast<int>(i)))
+      if (!feature.second->isCorrespondenceValid(static_cast<int>(i)))
         break;
 
       remaining_correspondences[number_valid_correspondences] =
